@@ -26,10 +26,7 @@ setup(
              'avi/migrationtools/ansible/avi_config_to_ansible.py',
              'avi/migrationtools/f5_discovery.py',
              'avi/migrationtools/nsxt_converter/nsxt_converter.py',
-             'avi/migrationtools/nsxt_converter/install_nsx_dependencies.py',
-             'avi/migrationtools/nsxt_converter/nsxt_traffic_cutover.py',
-             'avi/migrationtools/nsxt_converter/nsxt_rollback.py',
-             'avi/migrationtools/nsxt_converter/nsxt_cleanup.py'],
+             'avi/migrationtools/nsxt_converter/install_nsx_dependencies.py'],
     classifiers=[
         'Operating System :: OS Independent',
         'Programming Language :: Python',
@@ -41,7 +38,7 @@ setup(
     install_requires=['pyyaml', 'requests', 'pyparsing', 'paramiko', 'avisdk',
                       'pycrypto', 'ecdsa', 'pyOpenssl', 'nose-html-reporting',
                       'nose-testconfig', 'ConfigParser', 'xlsxwriter', 'jinja2',
-                      'pandas>=1.5.0', 'openpyxl', 'appdirs',  'pexpect',
+                      'pandas', 'openpyxl', 'appdirs',  'pexpect',
                       'unittest2', 'networkx', 'xmltodict'],
     package_data={'avi': ['*.cfg', '*.conf', '*.crt', '*.crl', '*.json',
                           '*.jinja', '*.key', '*.pem', '*.xml',
